from django.contrib.auth.models import Permission
from django.test import tag
from django.urls import reverse

from accounts.models import User
from guichet.models import Event, Registration, LydiaAccount
from guichet.tests import CustomTestCase


class LydiaTest(CustomTestCase):
    fixtures = ["test_guichet_users", "test_guichet_views"]

    def setUp(self):
        self.event = Event.objects.get(pk=1)
        self.ticket = self.event.tickets.get(id=1)
        self.ticket.online_payment = True
        self.ticket.save()
        self.user = User.objects.get(login_inp_net="testone")
        p = Permission.objects.get(codename="add_event")
        self.user.user_permissions.add(p)
        self.user.save()
        self.client.force_login(self.user)
        self.reg = Registration(ticket=self.ticket, owner=self.user, conditions_accepted=True)
        self.reg.save()

    @tag("fast", "local")
    def test_create_lydia_account(self):
        response = self.client.get(reverse("add-event"))
        self.assertEqual(response.status_code, 200)
        self.assertIn("Enregistrer un compte Lydia", response.content.decode())

        response = self.client.get(reverse("lydia-account"))
        self.assertEqual(response.status_code, 200)
        self.assertIn("Enregistrement d'un compte Lydia", response.content.decode())

    @tag("fast", "local")
    def test_show_registration_lydia_disabled(self):
        self.event.lydia_account = LydiaAccount.default_lydia_account()
        self.event.save()
        response = self.client.get(reverse("show-registration", args=[self.reg.id]))
        self.assertEqual(response.status_code, 200)
        self.assertNotIn("Payer avec Lydia", response.content.decode())

    @tag("fast", "local")
    def test_show_registration_lydia_enabled(self):
        self.event.lydia_account = LydiaAccount.objects.filter(no_account=False).first()
        self.event.save()
        response = self.client.get(reverse("show-registration", args=[self.reg.id]))
        self.assertEqual(response.status_code, 200)
        self.assertIn("Payer avec Lydia", response.content.decode())

    @tag("fast", "local")
    def test_payment_view(self):
        response = self.client.get(reverse("lydia-payment", args=[self.reg.id]))
        self.assertEqual(response.status_code, 200)
        self.assertIn("Paiement par Lydia", response.content.decode())
